@@ -14,6 +14,7 @@ from ..Exceptions import MergeConflict
 from ..Exceptions import NoChangesToCommitError
 from ..Exceptions import NoRemoteDefined
 from ..Exceptions import ProjectValidationError
+from .._private.readme_compiler import ReadmeCompiler
 from ..migration import getLatestRevision
 from ..tuples.git_commit_tuple import GitCommitTuple
 
@@ -140,6 +141,15 @@ class GitLibMixin:
         )
         self.__isIndexDirty = True
 
+    def _writeReadme(self, content: str):
+        oid = self._repo.create_blob(content.encode())
+        # Ensure there is a __working__ branch present
+        self.prepareWorkingBranch()
+        self.__index.add(
+            pygit2.IndexEntry("README.md", oid, pygit2.GIT_FILEMODE_BLOB)
+        )
+        self.__isIndexDirty = True
+
     @classmethod
     def cloneGitRepo(
         cls,
@@ -419,22 +429,35 @@ class GitLibMixin:
             self._repo.create_branch(branchName, commit)
             self._repo.checkout(makeRef(branchName))
 
+    def canSquashCommit(self) -> bool:
+        working = self.__workingBranch
+        checkedOut = self.__checkedOutBranch
+
+        if working.target == checkedOut.target:
+            return False
+
+        return True
+
     def squashAndMergeWorking(self, mergeCommitMessage: str) -> None:
         if self._workingId is not None:
             raise Exception(
                 "Cannot squash and commit when modifying the working branch"
             )
 
+        if self.isDirty:
+            raise ChangesNotCommitedError(
+                "There are pending changes to be committed"
+            )
+
+        if not self.canSquashCommit():
+            raise NoChangesToCommitError(
+                "There are no pending changes to commit"
+            )
+
+        self._generateReadme()
+
         working = self.__workingBranch
         checkedOut = self.__checkedOutBranch
-        checkedOutBranchRef = checkedOut.name
-
-        if self.isDirty:
-            raise ChangesNotCommitedError()
-
-        if working.target == checkedOut.target:
-            raise NoChangesToCommitError("There are no changes to commit")
-
         checkedLastCommit = next(self._repo.walk(checkedOut.target), None)
 
         # Walk the commits till we find the previous common point
@@ -474,7 +497,7 @@ class GitLibMixin:
         # Reload the reference to the working branch
         working = self.__workingBranch
 
-        self._repo.checkout(checkedOutBranchRef)
+        self._repo.checkout(checkedOut.name)
         checkedOut.set_target(working.target)
         self._repo.reset(checkedOut.target, pygit2.GIT_RESET_HARD)
 
@@ -482,6 +505,12 @@ class GitLibMixin:
         # commit
         working.delete()
 
+    def _generateReadme(self) -> None:
+        readmeCompiler = ReadmeCompiler(self)
+        readmeContent = readmeCompiler.compile()
+        self._writeReadme(readmeContent)
+        self.commit("Updated README.md")
+
     def getCommits(self) -> list[GitCommitTuple]:
         for commit in self._repo.walk(self.__checkedOutBranch.target):
             gitCommit = GitCommitTuple()
